==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/sv.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Lagring inte tillgänglig",
    "Storage invalid" : "Lagring ogiltig",
    "Unknown error" : "Okänt fel",
    "Unable to set upload directory." : "Kan inte sätta mapp för uppladdning.",
    "Invalid Token" : "Ogiltig token",
    "No file was uploaded. Unknown error" : "Ingen fil uppladdad. Okänt fel",
    "There is no error, the file uploaded with success" : "Inga fel uppstod. Filen laddades upp utan problem.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Den uppladdade filen överskrider upload_max_filesize direktivet php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överskrider MAX_FILE_SIZE direktivet som har angetts i HTML formuläret",
    "The uploaded file was only partially uploaded" : "Den uppladdade filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "En temporär mapp saknas",
    "Failed to write to disk" : "Misslyckades spara till disk",
    "Not enough storage available" : "Inte tillräckligt med lagringsutrymme tillgängligt",
    "The target folder has been moved or deleted." : "Målmappen har flyttats eller tagits bort.",
    "Upload failed. Could not find uploaded file" : "Uppladdning misslyckades. Kunde inte hitta den uppladdade filen",
    "Upload failed. Could not get file info." : "Uppladdning misslyckades. Gick inte att hämta filinformation.",
    "Invalid directory." : "Felaktig mapp.",
    "Files" : "Filer",
    "All files" : "Alla filer",
    "Favorites" : "Favoriter",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Total file size {size1} exceeds upload limit {size2}" : "Totala filstorleken {size1} överskrider uppladdningsgränsen {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Could not get result from server." : "Gick inte att hämta resultat från server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filuppladdning pågår. Lämnar du sidan så avbryts uppladdningen.",
    "Actions" : "Åtgärder",
    "Download" : "Ladda ner",
    "Rename" : "Byt namn",
    "Delete" : "Radera",
    "Disconnect storage" : "Koppla bort lagring",
    "Unshare" : "Sluta dela",
    "Details" : "Detaljer",
    "Select" : "Välj",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Vänligen välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No entries in this folder match '{filter}'" : "Inga poster i denna mapp match \"{filter}\"",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltligt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%)",
    "Path" : "sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoritiserad",
    "Favorite" : "Favorit",
    "Folder" : "Mapp",
    "New folder" : "Ny mapp",
    "{newname} already exists" : "{newname}  existerar redan",
    "Upload" : "Ladda upp",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En ny fil eller mapp har blivit <strong>raderad</strong>",
    "A file or folder has been <strong>restored</strong>" : "En ny fil eller mapp har blivit <strong>återskapad</strong>",
    "You created %1$s" : "Du skapade %1$s",
    "%2$s created %1$s" : "%2$s skapade %1$s",
    "%1$s was created in a public folder" : "%1$s skapades i en publik mapp",
    "You changed %1$s" : "Du ändrade %1$s",
    "%2$s changed %1$s" : "%2$s ändrade %1$s",
    "You deleted %1$s" : "Du raderade %1$s",
    "%2$s deleted %1$s" : "%2$s raderade %1$s",
    "You restored %1$s" : "Du återkapade %1$s",
    "%2$s restored %1$s" : "%2$s återskapade %1$s",
    "Changed by %2$s" : "Ändrad av %2$s",
    "Deleted by %2$s" : "Bortagen av %2$s",
    "Restored by %2$s" : "Återställd av %2$s",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "File handling" : "Filhantering",
    "Maximum upload size" : "Maximal storlek att ladda upp",
    "max. possible: " : "max. möjligt:",
    "Save" : "Spara",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta cirka 5 minuter för ändringarna att träda i kraft.",
    "Missing permissions to edit from here." : "Saknar rättigheter att ändra härifrån.",
    "Settings" : "Inställningar",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Använd denna adress till <a href=\"%s\" target=\"_blank\">nå dina Filer via WebDAV</a>",
    "Cancel upload" : "Avbryt uppladdning",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "No entries found in this folder" : "nga Filer hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "No favorites" : "Inga favoriter",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar du markerat som favoriter kommer visas här",
    "Text file" : "Textfil",
    "New text file.txt" : "nytextfil.txt",
    "Changed by %2$s" : "Ändrad av %2$s",
    "Deleted by %2$s" : "Bortagen av %2$s",
    "Restored by %2$s" : "Återställd av %2$s",
    "You changed %1$s" : "Du ändrade %1$s",
    "You created %1$s" : "Du skapade %1$s",
    "You deleted %1$s" : "Du raderade %1$s",
    "You restored %1$s" : "Du återkapade %1$s"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/sv.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Lagring inte tillgänglig",
    "Storage invalid" : "Lagring ogiltig",
    "Unknown error" : "Okänt fel",
    "Unable to set upload directory." : "Kan inte sätta mapp för uppladdning.",
    "Invalid Token" : "Ogiltig token",
    "No file was uploaded. Unknown error" : "Ingen fil uppladdad. Okänt fel",
    "There is no error, the file uploaded with success" : "Inga fel uppstod. Filen laddades upp utan problem.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Den uppladdade filen överskrider upload_max_filesize direktivet php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överskrider MAX_FILE_SIZE direktivet som har angetts i HTML formuläret",
    "The uploaded file was only partially uploaded" : "Den uppladdade filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "En temporär mapp saknas",
    "Failed to write to disk" : "Misslyckades spara till disk",
    "Not enough storage available" : "Inte tillräckligt med lagringsutrymme tillgängligt",
    "The target folder has been moved or deleted." : "Målmappen har flyttats eller tagits bort.",
    "Upload failed. Could not find uploaded file" : "Uppladdning misslyckades. Kunde inte hitta den uppladdade filen",
    "Upload failed. Could not get file info." : "Uppladdning misslyckades. Gick inte att hämta filinformation.",
    "Invalid directory." : "Felaktig mapp.",
    "Files" : "Filer",
    "All files" : "Alla filer",
    "File could not be found" : "Fil kunde inte hittas",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Favorites" : "Favoriter",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Total file size {size1} exceeds upload limit {size2}" : "Totala filstorleken {size1} överskrider uppladdningsgränsen {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Error uploading file \"{fileName}\": {message}" : "Fel vid uppladdning av fil \"{fileName}\": {message}",
    "Could not get result from server." : "Gick inte att hämta resultat från server.",
    "Uploading..." : "Laddar upp...",
    "..." : "...",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} timme/ar kvar",
    "{hours}:{minutes}h" : "{hours}:{minutes}",
    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minut(er) kvar",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}",
    "{seconds} second{plural_s} left" : "{seconds} sekund(er) kvar",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Alldeles strax...",
    "Soon..." : "Snart...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filuppladdning pågår. Lämnar du sidan så avbryts uppladdningen.",
    "Actions" : "Åtgärder",
    "Download" : "Ladda ner",
    "Rename" : "Byt namn",
    "Delete" : "Radera",
    "Disconnect storage" : "Koppla bort lagring",
    "Unshare" : "Sluta dela",
    "Details" : "Detaljer",
    "Select" : "Välj",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Vänligen välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No entries in this folder match '{filter}'" : "Inga poster i denna mapp match \"{filter}\"",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltligt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matchar '{filter}'","matcha '{filter}'"],
    "Path" : "sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoriserad",
    "Favorite" : "Favorit",
    "Local link" : "Lokal länk",
    "Folder" : "Mapp",
    "New folder" : "Ny mapp",
    "{newname} already exists" : "{newname}  existerar redan",
    "Upload" : "Ladda upp",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa notiser om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast ström)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En ny fil eller mapp har blivit <strong>raderad</strong>",
    "A file or folder has been <strong>restored</strong>" : "En ny fil eller mapp har blivit <strong>återskapad</strong>",
    "You created %1$s" : "Du skapade %1$s",
    "%2$s created %1$s" : "%2$s skapade %1$s",
    "%1$s was created in a public folder" : "%1$s skapades i en publik mapp",
    "You changed %1$s" : "Du ändrade %1$s",
    "%2$s changed %1$s" : "%2$s ändrade %1$s",
    "You deleted %1$s" : "Du raderade %1$s",
    "%2$s deleted %1$s" : "%2$s raderade %1$s",
    "You restored %1$s" : "Du återkapade %1$s",
    "%2$s restored %1$s" : "%2$s återskapade %1$s",
    "Changed by %2$s" : "Ändrad av %2$s",
    "Deleted by %2$s" : "Bortagen av %2$s",
    "Restored by %2$s" : "Återställd av %2$s",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "File handling" : "Filhantering",
    "Maximum upload size" : "Maximal storlek att ladda upp",
    "max. possible: " : "max. möjligt:",
    "Save" : "Spara",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta cirka 5 minuter för ändringarna att träda i kraft.",
    "Missing permissions to edit from here." : "Saknar rättigheter att ändra härifrån.",
    "Settings" : "Inställningar",
    "Show hidden files" : "Visa dolda filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Använd den här adressen för att <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">komma åt dina filer via WebDAV</a>",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "No entries found in this folder" : "Inga innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "No favorites" : "Inga favoriter",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar du markerat som favoriter kommer att visas här",
    "Text file" : "Textfil",
    "New text file.txt" : "nytextfil.txt"
},
"nplurals=2; plural=(n != 1);");
